<?php
// Own namespace
namespace CoreFramework\Factory\News;

// Import framework stuff
use CoreFramework\Factory\BaseFactory;
use CoreFramework\Factory\ObjectFactory;
use CoreFramework\Request\Requestable;

/**
 * A news factory for web pages
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class HtmlNewsFactory extends BaseFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Singleton getter for a special factory instance depending on the given
	 * request
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return	$factoryInstance	An instance of a HtmlNewsFactory class
	 */
	public static final function createFactoryByRequest (Requestable $requestInstance) {
		// Set default news reader class
		$configEntry = 'news_reader_class';

		// Get "page"
		$command = $requestInstance->getRequestElement('command');

		// Is 'command' used?
		if (!empty($command)) {
			// Then add it
			$configEntry = sprintf('news_reader_%s_class', $command);

			// Get 'action'
			$action = $requestInstance->getRequestElement('action');

			// Is it also there?
			if (!empty($action)) {
				// Then use both for config entry
				$configEntry = sprintf('news_reader_%s_%s_class', $command, $action);
			} // END - if
		} // END - if

		// Get the news reader class name from config
		$className = $requestInstance->getConfigInstance()->getConfigEntry($configEntry);

		// Once we have that name, try to load initialize it
		$newsInstance = ObjectFactory::createObjectByName($className, array($requestInstance));

		// Initialize the reader
		$newsInstance->initializeReader();

		// Return the prepared factory instance
		return $newsInstance;
	}

}
